pub struct ScanRequest {
pub txn_id: u64,
pub scan_type: ScanTypes,
pub channel_list: Vec<ChannelNumber>,
pub ssid_list: Vec<Vec<u8>>,
pub probe_delay: u32,
pub min_channel_time: u32,
pub max_channel_time: u32,
}Fields
txn_id: u64scan_type: ScanTypeschannel_list: Vec<ChannelNumber>List of channels to scan on. An empty list of channels will cause a scan request to immediately return a ScanEnd with code INVALID_ARGS.
Invalid channel numbers will be silently ignored. The validity of a channel number depends on the current regulatory region, and MLME does not control or know this setting.
ssid_list: Vec<Vec<u8>>List of SSIDs to scan for. An empty list of ssids is the same as specifying a list containing only the wildcard SSID.
There is no limit on the number of SSIDs specified. A large number of SSIDs may result in extended scan times because of hardware limitations on the number of SSIDs permitted per scan request and the technical limitation in IEEE 802.11-2016 that limits the number of SSIDs in a single Probe Request frame to ieee80211.SSID_LIST_MAX SSIDs.
probe_delay: u32min_channel_time: u32max_channel_time: u32Trait Implementations
Sourceimpl Clone for ScanRequest
impl Clone for ScanRequest
Sourcefn clone(&self) -> ScanRequest
fn clone(&self) -> ScanRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ScanRequest
impl Debug for ScanRequest
Sourceimpl<D: ResourceDialect> Decode<ScanRequest, D> for ScanRequest
impl<D: ResourceDialect> Decode<ScanRequest, D> for ScanRequest
Sourceimpl<D: ResourceDialect> Encode<ScanRequest, D> for &ScanRequest
impl<D: ResourceDialect> Encode<ScanRequest, D> for &ScanRequest
Sourceimpl<D: ResourceDialect, T0: Encode<u64, D>, T1: Encode<ScanTypes, D>, T2: Encode<Vector<ChannelNumber, 256>, D>, T3: Encode<UnboundedVector<Vector<u8, 32>>, D>, T4: Encode<u32, D>, T5: Encode<u32, D>, T6: Encode<u32, D>> Encode<ScanRequest, D> for (T0, T1, T2, T3, T4, T5, T6)
impl<D: ResourceDialect, T0: Encode<u64, D>, T1: Encode<ScanTypes, D>, T2: Encode<Vector<ChannelNumber, 256>, D>, T3: Encode<UnboundedVector<Vector<u8, 32>>, D>, T4: Encode<u32, D>, T5: Encode<u32, D>, T6: Encode<u32, D>> Encode<ScanRequest, D> for (T0, T1, T2, T3, T4, T5, T6)
Sourceimpl PartialEq for ScanRequest
impl PartialEq for ScanRequest
impl Persistable for ScanRequest
impl StructuralPartialEq for ScanRequest
Sourceimpl TypeMarker for ScanRequest
impl TypeMarker for ScanRequest
Sourcetype Owned = ScanRequest
type Owned = ScanRequest
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for ScanRequest
impl ValueTypeMarker for ScanRequest
Sourcetype Borrowed<'a> = &'a ScanRequest
type Borrowed<'a> = &'a ScanRequest
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read more